@@ -1,9 +1,16 @@
 # coding=utf-8
 from __future__ import absolute_import
+from __future__ import print_function
+import six
+from future import standard_library
+standard_library.install_aliases()
 import click
 from tqdm import tqdm
 import psycopg2
-import ConfigParser
+if six.PY2:
+    import ConfigParser as configparser
+else:
+    import configparser
 from osconf import config_from_environment
 
 
@@ -24,7 +31,7 @@ class JSONParamType(click.ParamType):
 def oopgrade(ctx, config):
     ctx.obj = {}
     if config:
-        conf = ConfigParser.ConfigParser()
+        conf = configparser.ConfigParser()
         conf.read(config)
         ctx.obj = dict(conf.items('options'))
     envconf = config_from_environment('OPENERP')
@@ -68,8 +75,13 @@ def install(conf):
 @click.option('--channel')
 @click.argument('method')
 @click.option('--kwargs', type=JSONParamType())
+@click.option('--n-retries', default=0, type=click.INT, help='Will retry method n times')
+@click.option(
+    '--on-max-retries-method', type=click.STRING, help='If fails n times tou can provide alternative method'
+)
+@click.option('--on-max-retries-kwargs', type=JSONParamType(), help='Arguments for alternative method')
 @click.pass_obj
-def pubsub(ctx, channel, method, kwargs):
+def pubsub(ctx, channel, method, kwargs, n_retries, on_max_retries_method, on_max_retries_kwargs):
     import json
     from oopgrade.pubsub import send_msg
     secret = ctx.get('secret')
@@ -82,9 +94,13 @@ def pubsub(ctx, channel, method, kwargs):
     if not db_name:
         raise ValueError('Databse (key: db_name) not found in config')
     channel = '{}.{}'.format(db_name, channel)
-    msg = json.dumps({
+    msg = {
         'method': method,
-        'kwargs': kwargs or {}
-    })
+        'kwargs': kwargs or {},
+        'n_retries': n_retries or 0,
+        'on_max_retries_method': on_max_retries_method or False,
+        'on_max_retries_kwargs': on_max_retries_kwargs or {},
+    }
+    msg = json.dumps(msg)
     sent_to = send_msg(redis_url, secret, channel, msg)
     print('-> Message sent to {} nodes'.format(sent_to))
